Structs
- Dependency
Status - Result of checking a single dependency.
Functions
- check_
dependencies - Check whether each dependency’s binary is available on the system and whether its version satisfies any declared constraint.
- check_
pipeline_ dependencies - Check dependencies for a pipeline definition and return an error if any are missing.
- check_
pipeline_ secrets - Check that all required secrets declared by a pipeline are available.
- collect_
all_ dependencies - Collect unique dependencies from ALL registered processors in the registry.
- collect_
pipeline_ dependencies - Collect unique dependencies required by a pipeline definition.